@@ -1,7 +1,7 @@
 # ===========================================================================
 # File: "runit_tau.R"
 #                        Created: 2012-11-13 11:28:57
-#              Last modification: 2015-08-31 10:09:41
+#              Last modification: 2016-05-27 11:04:56
 # Author: Bernard Desgraupes
 # e-mail: <bernard.desgraupes@u-paris10.fr>
 # Unit test file for the R package clusterCrit.
@@ -14,7 +14,7 @@ test.tau <- function() {
 	load(file=dataPath, envir=.GlobalEnv)
 	idx <- intCriteria(traj_400_4, part_400_4[[4]], c("Tau"))
 	cat(paste("\nFound idx =",idx))
-	val <- -0.610833639021322
+	val <- 0.610833639021322
 	cat(paste("\nShould be =",val,"\n"))
 	checkEqualsNumeric(idx[[1]],val)
 }
